@@ -19,6 +19,6 @@ from psiz.agents.base import Agent
 from psiz.agents.rank_agent import RankAgent
 
 __all__ = [
-    'Agent',
-    'RankAgent'
+    "Agent",
+    "RankAgent",
 ]
