@@ -18,7 +18,4 @@
 from psiz.catalog.catalog import Catalog
 from psiz.catalog.load_catalog import load_catalog
 
-__all__ = [
-    'Catalog',
-    'load_catalog'
-]
+__all__ = ["Catalog", "load_catalog"]
