@@ -17,4 +17,6 @@
 
 from psiz.datasets.load_dataset import load_dataset
 
-__all__ = ['load_dataset']
+__all__ = [
+    "load_dataset",
+]
