@@ -13,19 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ============================================================================
-"""Keras specific initialization file.
+"""Module of Keras classes."""
 
-Modules:
-    callbacks
-    constraints
-    initializers
-    layers
-    losses
-    regularizers
-
-"""
-
-import psiz.keras.callbacks
 import psiz.keras.constraints
 import psiz.keras.initializers
 import psiz.keras.layers
@@ -36,4 +25,6 @@ import psiz.keras.regularizers
 # mirror TensorFlow organization.
 from psiz.keras.models.stochastic_model import StochasticModel
 
-__all__ = ['StochasticModel']
+__all__ = [
+    "StochasticModel",
+]
