@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ============================================================================
-"""Keras constraints initialization file."""
+"""Module of Keras constraints."""
 
 from psiz.keras.constraints.center import Center
 from psiz.keras.constraints.greater_equal_than import GreaterEqualThan
@@ -24,11 +24,11 @@ from psiz.keras.constraints.min_max import MinMax
 from psiz.keras.constraints.non_neg_norm import NonNegNorm
 
 __all__ = [
-    'Center',
-    'GreaterEqualThan',
-    'GreaterThan',
-    'LessEqualThan',
-    'LessThan',
-    'MinMax',
-    'NonNegNorm'
+    "Center",
+    "GreaterEqualThan",
+    "GreaterThan",
+    "LessEqualThan",
+    "LessThan",
+    "MinMax",
+    "NonNegNorm",
 ]
