@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ============================================================================
-"""Keras layers initialization file."""
+"""Module of Keras layers."""
 
 from psiz.keras.layers.drop import Drop
 from psiz.keras.layers.variational import Variational
@@ -50,37 +50,37 @@ from psiz.keras.layers.similarities.inverse import InverseSimilarity
 from psiz.keras.layers.similarities.students_t import StudentsTSimilarity
 
 __all__ = [
-    'RankSimilarityBase',
-    'RankSimilarity',
-    'RankSimilarityCell',
-    'RateSimilarityBase',
-    'RateSimilarity',
-    'RateSimilarityCell',
-    'ALCOVECell',
-    'RankBehavior',
-    'RateBehavior',
-    'Minkowski',
-    'MinkowskiStochastic',
-    'MinkowskiVariational',
-    'EmbeddingGammaDiag',
-    'EmbeddingLaplaceDiag',
-    'EmbeddingLogNormalDiag',
-    'EmbeddingLogitNormalDiag',
-    'EmbeddingNormalDiag',
-    'EmbeddingShared',
-    'StochasticEmbedding',
-    'EmbeddingTruncatedNormalDiag',
-    'EmbeddingVariational',
-    'Gate',
-    'BraidGate',
-    'BranchGate',
-    'GateAdapter',
-    'SplitGate',
-    'Drop',
-    'DistanceBased',
-    'ExponentialSimilarity',
-    'HeavyTailedSimilarity',
-    'InverseSimilarity',
-    'StudentsTSimilarity',
-    'Variational'
+    "RankSimilarityBase",
+    "RankSimilarity",
+    "RankSimilarityCell",
+    "RateSimilarityBase",
+    "RateSimilarity",
+    "RateSimilarityCell",
+    "ALCOVECell",
+    "RankBehavior",
+    "RateBehavior",
+    "Minkowski",
+    "MinkowskiStochastic",
+    "MinkowskiVariational",
+    "EmbeddingGammaDiag",
+    "EmbeddingLaplaceDiag",
+    "EmbeddingLogNormalDiag",
+    "EmbeddingLogitNormalDiag",
+    "EmbeddingNormalDiag",
+    "EmbeddingShared",
+    "StochasticEmbedding",
+    "EmbeddingTruncatedNormalDiag",
+    "EmbeddingVariational",
+    "Gate",
+    "BraidGate",
+    "BranchGate",
+    "GateAdapter",
+    "SplitGate",
+    "Drop",
+    "DistanceBased",
+    "ExponentialSimilarity",
+    "HeavyTailedSimilarity",
+    "InverseSimilarity",
+    "StudentsTSimilarity",
+    "Variational",
 ]
