@@ -23,16 +23,14 @@ Classes:
 import copy
 
 import tensorflow as tf
-from tensorflow.python.keras import backend as K
+from tensorflow.keras import backend as K
 
 import psiz.keras.constraints as pk_constraints
 from psiz.keras.layers.gates.gate_adapter import GateAdapter
 from psiz.tf.ops.wpnorm import wpnorm
 
 
-@tf.keras.utils.register_keras_serializable(
-    package='psiz.keras', name='ALCOVECell'
-)
+@tf.keras.utils.register_keras_serializable(package="psiz.keras", name="ALCOVECell")
 class ALCOVECell(tf.keras.layers.Layer):
     """An RNN-compatible cell implementing ALCOVE."""
 
@@ -97,15 +95,13 @@ class ALCOVECell(tf.keras.layers.Layer):
         self.similarity = similarity
 
         if data_scope is None:
-            data_scope = 'categorize'
+            data_scope = "categorize"
         self.data_scope = data_scope
 
         # Configure percept adapter.
         if percept_adapter is None:
             # Default adapter has no gating keys.
-            percept_adapter = GateAdapter(
-                format_inputs_as_tuple=True
-            )
+            percept_adapter = GateAdapter(format_inputs_as_tuple=True)
         # NOTE: The second adapter uses the same underlying embedding and
         # gate weights, but takes a different set of indices.
         alcove_adapter = percept_adapter.__class__.from_config(
@@ -115,10 +111,8 @@ class ALCOVECell(tf.keras.layers.Layer):
         self._alcove_adapter = alcove_adapter
 
         # Set required input keys.
-        self.percept_adapter.input_keys = [
-            data_scope + '_alcove_stimset_samples'
-        ]
-        self._alcove_adapter.input_keys = [data_scope + '_alcove_idx']
+        self.percept_adapter.input_keys = [data_scope + "_alcove_stimset_samples"]
+        self._alcove_adapter.input_keys = [data_scope + "_alcove_idx"]
 
         # Misc. attributes.
         self.units = units
@@ -135,7 +129,7 @@ class ALCOVECell(tf.keras.layers.Layer):
         # Satisfy RNNCell contract.
         self.state_size = [
             tf.TensorShape([1, self.n_dim]),
-            tf.TensorShape([self.n_rbf, units])
+            tf.TensorShape([self.n_rbf, units]),
         ]
         self.output_size = tf.TensorShape([units])
 
@@ -144,7 +138,7 @@ class ALCOVECell(tf.keras.layers.Layer):
         # Process `rho`.
         self.rho_trainable = self.trainable and rho_trainable
         if rho_initializer is None:
-            rho_initializer = tf.random_uniform_initializer(1., 2.)
+            rho_initializer = tf.random_uniform_initializer(1.0, 2.0)
         self.rho_initializer = tf.keras.initializers.get(rho_initializer)
         self.rho_regularizer = tf.keras.regularizers.get(rho_regularizer)
         if rho_constraint is None:
@@ -152,16 +146,19 @@ class ALCOVECell(tf.keras.layers.Layer):
         self.rho_constraint = tf.keras.constraints.get(rho_constraint)
         with tf.name_scope(self.name):
             self.rho = self.add_weight(
-                shape=[], initializer=self.rho_initializer,
-                regularizer=self.rho_regularizer, trainable=self.rho_trainable,
-                name="rho", dtype=K.floatx(),
-                constraint=self.rho_constraint
+                shape=[],
+                initializer=self.rho_initializer,
+                regularizer=self.rho_regularizer,
+                trainable=self.rho_trainable,
+                name="rho",
+                dtype=K.floatx(),
+                constraint=self.rho_constraint,
             )
 
         # Process `temperature`.
         self.temperature_trainable = self.trainable and temperature_trainable
         if temperature_initializer is None:
-            temperature_initializer = tf.random_uniform_initializer(1., 5.)
+            temperature_initializer = tf.random_uniform_initializer(1.0, 5.0)
         self.temperature_initializer = tf.keras.initializers.get(
             temperature_initializer
         )
@@ -169,18 +166,17 @@ class ALCOVECell(tf.keras.layers.Layer):
             temperature_regularizer
         )
         if temperature_constraint is None:
-            temperature_constraint = pk_constraints.GreaterEqualThan(
-                min_value=0.0
-            )
-        self.temperature_constraint = tf.keras.constraints.get(
-            temperature_constraint
-        )
+            temperature_constraint = pk_constraints.GreaterEqualThan(min_value=0.0)
+        self.temperature_constraint = tf.keras.constraints.get(temperature_constraint)
         with tf.name_scope(self.name):
             self.temperature = self.add_weight(
-                shape=[], initializer=self.temperature_initializer,
+                shape=[],
+                initializer=self.temperature_initializer,
                 regularizer=self.temperature_regularizer,
-                trainable=self.temperature_trainable, name="temperature",
-                dtype=K.floatx(), constraint=self.temperature_constraint
+                trainable=self.temperature_trainable,
+                name="temperature",
+                dtype=K.floatx(),
+                constraint=self.temperature_constraint,
             )
 
         # Process `lr_attention`.
@@ -194,28 +190,23 @@ class ALCOVECell(tf.keras.layers.Layer):
             lr_attention_regularizer
         )
         if lr_attention_constraint is None:
-            lr_attention_constraint = pk_constraints.GreaterEqualThan(
-                min_value=0.0
-            )
-        self.lr_attention_constraint = tf.keras.constraints.get(
-            lr_attention_constraint
-        )
+            lr_attention_constraint = pk_constraints.GreaterEqualThan(min_value=0.0)
+        self.lr_attention_constraint = tf.keras.constraints.get(lr_attention_constraint)
         with tf.name_scope(self.name):
             self.lr_attention = self.add_weight(
-                shape=[], initializer=self.lr_attention_initializer,
+                shape=[],
+                initializer=self.lr_attention_initializer,
                 regularizer=self.lr_attention_regularizer,
-                trainable=self.lr_attention_trainable, name="lr_attention",
-                dtype=K.floatx(), constraint=self.lr_attention_constraint
+                trainable=self.lr_attention_trainable,
+                name="lr_attention",
+                dtype=K.floatx(),
+                constraint=self.lr_attention_constraint,
             )
 
         # Process `lr_association`.
-        self.lr_association_trainable = (
-            self.trainable and lr_association_trainable
-        )
+        self.lr_association_trainable = self.trainable and lr_association_trainable
         if lr_association_initializer is None:
-            lr_association_initializer = tf.random_uniform_initializer(
-                0.0, 0.1
-            )
+            lr_association_initializer = tf.random_uniform_initializer(0.0, 0.1)
         self.lr_association_initializer = tf.keras.initializers.get(
             lr_association_initializer
         )
@@ -223,18 +214,19 @@ class ALCOVECell(tf.keras.layers.Layer):
             lr_association_regularizer
         )
         if lr_association_constraint is None:
-            lr_association_constraint = pk_constraints.GreaterEqualThan(
-                min_value=0.0
-            )
+            lr_association_constraint = pk_constraints.GreaterEqualThan(min_value=0.0)
         self.lr_association_constraint = tf.keras.constraints.get(
             lr_association_constraint
         )
         with tf.name_scope(self.name):
             self.lr_association = self.add_weight(
-                shape=[], initializer=self.lr_association_initializer,
+                shape=[],
+                initializer=self.lr_association_initializer,
                 regularizer=self.lr_association_regularizer,
-                trainable=self.lr_association_trainable, name="lr_association",
-                dtype=K.floatx(), constraint=self.lr_association_constraint
+                trainable=self.lr_association_trainable,
+                name="lr_association",
+                dtype=K.floatx(),
+                constraint=self.lr_association_constraint,
             )
 
     def get_initial_state(self, inputs=None, batch_size=None, dtype=None):
@@ -250,22 +242,23 @@ class ALCOVECell(tf.keras.layers.Layer):
         """
         initial_state = [
             tf.ones([batch_size, 1, self.n_dim]) / self.n_dim,
-            tf.zeros([batch_size, self.n_rbf, self.units])
+            tf.zeros([batch_size, self.n_rbf, self.units]),
         ]
         return initial_state
 
     def build(self, input_shape):
         """Build.
 
-        Expect:
-        "categorize_stimulus_set":
-            shape =(batch_size, [1,])
+        Args:
+            input_shape: Expects a dictionary that contains
+                "categorize_stimulus_set" with shape =
+                (batch_size, [1,]).
 
         """
         # We assume axes semantics based on relative position from last axis.
         stimuli_axis = -1
         # Convert from *relative* axis index to *absolute* axis index.
-        n_axis = len(input_shape[self.data_scope + '_stimulus_set'])
+        n_axis = len(input_shape[self.data_scope + "_stimulus_set"])
         self._stimuli_axis = tf.constant(n_axis + stimuli_axis)
 
         # Precompute indices for all ALCOVE RBFs.
@@ -275,22 +268,18 @@ class ALCOVECell(tf.keras.layers.Layer):
         """Call.
 
         Args:
-            inputs: A dictionary containting the following information:
-                stimulus_set: The indices of the stimuli.
-                    shape=(batch_size, 1)
-                objective_query_label: One-hot encoding of (objectively
-                    correct) query label.
-                    shape=(batch_size, n_output)
-                gate_weights (optional): Tensor(s) containing gate
-                    weights. The actual key value(s) will depend on how
-                    the user initialized the layer.
-            states:
-                states[0]: A tensor representing batch-specific
-                    attention weights that modify the Minkowski
-                    distance.
-                states[1]: A tensor representing batch-specific
-                    association weights that map RBF activity to
-                    class output activitiy.
+            inputs["stimulus_set"]: The indices of the stimuli.
+                shape=(batch_size, 1)
+            inputs["objective_query_label"]: One-hot encoding of
+                (objectively correct) query label.
+                shape=(batch_size, n_output)
+            inputs["gate_weights"] (optional): Tensor(s) containing gate
+                weights. The actual key value(s) will depend on how
+                the user initialized the layer.
+            states[0]: A tensor representing batch-specific attention
+                weights that modify the Minkowski distance.
+            states[1]: A tensor representing batch-specific association
+                weights that map RBF activity to class output activitiy.
 
         """
         # NOTE: The inputs are copied, because modifying the original `inputs`
@@ -298,25 +287,24 @@ class ALCOVECell(tf.keras.layers.Layer):
         # a model.
         inputs_copied = copy.copy(inputs)
 
-        batch_size = tf.shape(
-            inputs_copied[self.data_scope + '_stimulus_set']
-        )[0]
+        batch_size = tf.shape(inputs_copied[self.data_scope + "_stimulus_set"])[0]
 
-        stimulus_set = inputs_copied[self.data_scope + '_stimulus_set']
-        objective_query_label_idx = (
-            inputs_copied[self.data_scope + '_objective_query_label']
-        )
+        stimulus_set = inputs_copied[self.data_scope + "_stimulus_set"]
+        objective_query_label_idx = inputs_copied[
+            self.data_scope + "_objective_query_label"
+        ]
 
         attention = states[0]  # Previous attention weights state.
         association = states[1]  # Previous association weights state.
 
         # Embed stimuli indices in n-dimensional space.
-        inputs_copied.update({
-            self.data_scope + '_alcove_stimset_samples': stimulus_set,
-            self.data_scope + '_alcove_idx': tf.repeat(
-                self._alcove_idx, batch_size, axis=0
-            ),
-        })
+        inputs_copied.update(
+            {
+                self.data_scope + "_alcove_stimset_samples": stimulus_set,
+                self.data_scope
+                + "_alcove_idx": tf.repeat(self._alcove_idx, batch_size, axis=0),
+            }
+        )
         inputs_percept = self.percept_adapter(inputs_copied)
         z_in = self.percept(inputs_percept)
         # TensorShape=(batch_size, 1, n_dim])
@@ -329,9 +317,7 @@ class ALCOVECell(tf.keras.layers.Layer):
 
         # Use TensorFlow gradients to update model state.
         state_variables = [association, attention]
-        state_tape = tf.GradientTape(
-            watch_accessed_variables=False, persistent=True
-        )
+        state_tape = tf.GradientTape(watch_accessed_variables=False, persistent=True)
         with state_tape:
             state_tape.watch(state_variables)
 
@@ -348,9 +334,7 @@ class ALCOVECell(tf.keras.layers.Layer):
             # shape=(batch_size, units)
 
             # Compute loss.
-            loss = self.humble_teacher_loss(
-                objective_query_label_idx, x_out
-            )
+            loss = self.humble_teacher_loss(objective_query_label_idx, x_out)
             # shape=(batch_size, [n_sample])
         # Compute derivatives
         grad_attention = state_tape.gradient(loss, attention)
@@ -365,9 +349,7 @@ class ALCOVECell(tf.keras.layers.Layer):
         # Update states.
         attention_tplus1 = attention - (self.lr_attention * grad_attention)
         attention_tplus1 = tf.math.maximum(attention_tplus1, 0)
-        association_tplus1 = association - (
-            self.lr_association * grad_association
-        )
+        association_tplus1 = association - (self.lr_association * grad_association)
         states_tplus1 = [attention_tplus1, association_tplus1]
 
         return x_out_scaled, states_tplus1
@@ -425,58 +407,64 @@ class ALCOVECell(tf.keras.layers.Layer):
     def get_config(self):
         """Return layer configuration."""
         config = super(ALCOVECell, self).get_config()
-        config.update({
-            'units': self.units,
-            'percept': tf.keras.utils.serialize_keras_object(self.percept),
-            'similarity': tf.keras.utils.serialize_keras_object(
-                self.similarity
-            ),
-            'percept_adapter': tf.keras.utils.serialize_keras_object(
-                self.percept_adapter
-            ),
-            'rho_initializer':
-                tf.keras.initializers.serialize(self.rho_initializer),
-            'rho_regularizer':
-                tf.keras.regularizers.serialize(self.rho_regularizer),
-            'rho_constraint':
-                tf.keras.constraints.serialize(self.rho_constraint),
-            'rho_trainable': self.rho_trainable,
-            'temperature_initializer':
-                tf.keras.initializers.serialize(self.temperature_initializer),
-            'temperature_regularizer':
-                tf.keras.regularizers.serialize(self.temperature_regularizer),
-            'temperature_constraint':
-                tf.keras.constraints.serialize(self.temperature_constraint),
-            'temperature_trainable': self.temperature_trainable,
-            'lr_attention_initializer':
-                tf.keras.initializers.serialize(self.lr_attention_initializer),
-            'lr_attention_regularizer':
-                tf.keras.regularizers.serialize(self.lr_attention_regularizer),
-            'lr_attention_constraint':
-                tf.keras.constraints.serialize(self.lr_attention_constraint),
-            'lr_attention_trainable': self.lr_attention_trainable,
-            'lr_association_initializer': tf.keras.initializers.serialize(
-                self.lr_association_initializer
-            ),
-            'lr_association_regularizer': tf.keras.regularizers.serialize(
-                self.lr_association_regularizer
-            ),
-            'lr_association_constraint':
-                tf.keras.constraints.serialize(self.lr_association_constraint),
-            'lr_association_trainable': self.lr_association_trainable,
-        })
+        config.update(
+            {
+                "units": self.units,
+                "percept": tf.keras.utils.serialize_keras_object(self.percept),
+                "similarity": tf.keras.utils.serialize_keras_object(self.similarity),
+                "percept_adapter": tf.keras.utils.serialize_keras_object(
+                    self.percept_adapter
+                ),
+                "rho_initializer": tf.keras.initializers.serialize(
+                    self.rho_initializer
+                ),
+                "rho_regularizer": tf.keras.regularizers.serialize(
+                    self.rho_regularizer
+                ),
+                "rho_constraint": tf.keras.constraints.serialize(self.rho_constraint),
+                "rho_trainable": self.rho_trainable,
+                "temperature_initializer": tf.keras.initializers.serialize(
+                    self.temperature_initializer
+                ),
+                "temperature_regularizer": tf.keras.regularizers.serialize(
+                    self.temperature_regularizer
+                ),
+                "temperature_constraint": tf.keras.constraints.serialize(
+                    self.temperature_constraint
+                ),
+                "temperature_trainable": self.temperature_trainable,
+                "lr_attention_initializer": tf.keras.initializers.serialize(
+                    self.lr_attention_initializer
+                ),
+                "lr_attention_regularizer": tf.keras.regularizers.serialize(
+                    self.lr_attention_regularizer
+                ),
+                "lr_attention_constraint": tf.keras.constraints.serialize(
+                    self.lr_attention_constraint
+                ),
+                "lr_attention_trainable": self.lr_attention_trainable,
+                "lr_association_initializer": tf.keras.initializers.serialize(
+                    self.lr_association_initializer
+                ),
+                "lr_association_regularizer": tf.keras.regularizers.serialize(
+                    self.lr_association_regularizer
+                ),
+                "lr_association_constraint": tf.keras.constraints.serialize(
+                    self.lr_association_constraint
+                ),
+                "lr_association_trainable": self.lr_association_trainable,
+            }
+        )
         return config
 
     @classmethod
     def from_config(cls, config):
-        similarity_serial = config['similarity']
-        config['similarity'] = tf.keras.layers.deserialize(similarity_serial)
-        percept_serial = config['percept']
-        config['percept'] = tf.keras.layers.deserialize(percept_serial)
-        percept_adapter_serial = config['percept_adapter']
-        config['percept_adapter'] = tf.keras.layers.deserialize(
-            percept_adapter_serial
-        )
+        similarity_serial = config["similarity"]
+        config["similarity"] = tf.keras.layers.deserialize(similarity_serial)
+        percept_serial = config["percept"]
+        config["percept"] = tf.keras.layers.deserialize(percept_serial)
+        percept_adapter_serial = config["percept_adapter"]
+        config["percept_adapter"] = tf.keras.layers.deserialize(percept_adapter_serial)
         return cls(**config)
 
     def _precompue_alcove_indices(self):
