@@ -21,26 +21,30 @@ Classes:
 """
 
 import tensorflow as tf
-from tensorflow.python.keras import backend as K
+from tensorflow.keras import backend as K
 
 import psiz.keras.constraints as pk_constraints
 
 
 @tf.keras.utils.register_keras_serializable(
-    package='psiz.keras.layers', name='InverseSimilarity'
+    package="psiz.keras.layers", name="InverseSimilarity"
 )
 class InverseSimilarity(tf.keras.layers.Layer):
     """Inverse-distance similarity function.
 
     The inverse-distance similarity function is parameterized as:
-        s(x,y) = 1 / (d(x,y)**tau + mu),
+    s(x,y) = 1 / (d(x,y)**tau + mu),
     where x and y are n-dimensional vectors.
-
     """
 
     def __init__(
-            self, fit_tau=True, fit_mu=True, tau_initializer=None,
-            mu_initializer=None, **kwargs):
+        self,
+        fit_tau=True,
+        fit_mu=True,
+        tau_initializer=None,
+        mu_initializer=None,
+        **kwargs
+    ):
         """Initialize.
 
         Args:
@@ -56,29 +60,32 @@ class InverseSimilarity(tf.keras.layers.Layer):
 
         self.fit_tau = fit_tau
         if tau_initializer is None:
-            tau_initializer = tf.random_uniform_initializer(1., 2.)
+            tau_initializer = tf.random_uniform_initializer(1.0, 2.0)
         self.tau_initializer = tf.keras.initializers.get(tau_initializer)
         tau_trainable = self.trainable and self.fit_tau
         with tf.name_scope(self.name):
             self.tau = self.add_weight(
-                shape=[], initializer=self.tau_initializer,
-                trainable=tau_trainable, name="tau", dtype=K.floatx(),
-                constraint=pk_constraints.GreaterEqualThan(min_value=1.0)
+                shape=[],
+                initializer=self.tau_initializer,
+                trainable=tau_trainable,
+                name="tau",
+                dtype=K.floatx(),
+                constraint=pk_constraints.GreaterEqualThan(min_value=1.0),
             )
 
         self.fit_mu = fit_mu
         if mu_initializer is None:
-            mu_initializer = tf.random_uniform_initializer(0.0000000001, .001)
+            mu_initializer = tf.random_uniform_initializer(0.0000000001, 0.001)
         self.mu_initializer = tf.keras.initializers.get(tau_initializer)
         mu_trainable = self.trainable and self.fit_mu
         with tf.name_scope(self.name):
             self.mu = self.add_weight(
-                shape=[], initializer=self.tau_initializer,
+                shape=[],
+                initializer=self.tau_initializer,
                 trainable=mu_trainable,
-                name="mu", dtype=K.floatx(),
-                constraint=pk_constraints.GreaterEqualThan(
-                    min_value=2.2204e-16
-                )
+                name="mu",
+                dtype=K.floatx(),
+                constraint=pk_constraints.GreaterEqualThan(min_value=2.2204e-16),
             )
 
     def call(self, inputs):
@@ -96,14 +103,14 @@ class InverseSimilarity(tf.keras.layers.Layer):
     def get_config(self):
         """Return layer configuration."""
         config = super().get_config()
-        config.update({
-            'fit_tau': self.fit_tau,
-            'fit_mu': self.fit_mu,
-            'tau_initializer': tf.keras.initializers.serialize(
-                self.tau_initializer
-            ),
-            'mu_initializer': tf.keras.initializers.serialize(
-                self.mu_initializer
-            ),
-        })
+        config.update(
+            {
+                "fit_tau": self.fit_tau,
+                "fit_mu": self.fit_mu,
+                "tau_initializer": tf.keras.initializers.serialize(
+                    self.tau_initializer
+                ),
+                "mu_initializer": tf.keras.initializers.serialize(self.mu_initializer),
+            }
+        )
         return config
