@@ -22,36 +22,41 @@ Classes:
 """
 
 import tensorflow as tf
-from tensorflow.python.keras import backend as K
+from tensorflow.keras import backend as K
 
 import psiz.keras.constraints as pk_constraints
 
 
 @tf.keras.utils.register_keras_serializable(
-    package='psiz.keras.layers', name='StudentsTSimilarity'
+    package="psiz.keras.layers", name="StudentsTSimilarity"
 )
 class StudentsTSimilarity(tf.keras.layers.Layer):
     """Student's t-distribution similarity function.
 
     The Student's t-distribution similarity function is parameterized
     as:
-        s(x,y) = (1 + (((d(x,y)^tau)/alpha))^(-(alpha + 1)/2),
+    s(x,y) = (1 + (((d(x,y)^tau)/alpha))^(-(alpha + 1)/2),
     where x and y are n-dimensional vectors. The original Student-t
     kernel proposed by van der Maaten [1] uses a L2 distance (which is
     governed by the distance kernel), tau=2, and alpha=n_dim-1. By
     default, all variables are fit to the data.
 
     References:
-    [1] van der Maaten, L., & Weinberger, K. (2012, Sept). Stochastic
-        triplet embedding. In Machine learning for signal processing
-        (MLSP), 2012 IEEE international workshop on (p. 1-6).
-        doi:10.1109/MLSP.2012.6349720
+        [1] van der Maaten, L., & Weinberger, K. (2012, Sept).
+            Stochastic triplet embedding. In Machine learning for
+            signal processing (MLSP), 2012 IEEE international workshop
+            on (p. 1-6). doi:10.1109/MLSP.2012.6349720
 
     """
 
     def __init__(
-            self, fit_tau=True, fit_alpha=True,
-            tau_initializer=None, alpha_initializer=None, **kwargs):
+        self,
+        fit_tau=True,
+        fit_alpha=True,
+        tau_initializer=None,
+        alpha_initializer=None,
+        **kwargs
+    ):
         """Initialize.
 
         Args:
@@ -67,26 +72,32 @@ class StudentsTSimilarity(tf.keras.layers.Layer):
 
         self.fit_tau = fit_tau
         if tau_initializer is None:
-            tau_initializer = tf.random_uniform_initializer(1., 2.)
+            tau_initializer = tf.random_uniform_initializer(1.0, 2.0)
         self.tau_initializer = tf.keras.initializers.get(tau_initializer)
         tau_trainable = self.trainable and self.fit_tau
         with tf.name_scope(self.name):
             self.tau = self.add_weight(
-                shape=[], initializer=self.tau_initializer,
-                trainable=tau_trainable, name="tau", dtype=K.floatx(),
-                constraint=pk_constraints.GreaterEqualThan(min_value=1.0)
+                shape=[],
+                initializer=self.tau_initializer,
+                trainable=tau_trainable,
+                name="tau",
+                dtype=K.floatx(),
+                constraint=pk_constraints.GreaterEqualThan(min_value=1.0),
             )
 
         self.fit_alpha = fit_alpha
         if alpha_initializer is None:
-            alpha_initializer = tf.random_uniform_initializer(1., 10.)
+            alpha_initializer = tf.random_uniform_initializer(1.0, 10.0)
         self.alpha_initializer = tf.keras.initializers.get(alpha_initializer)
         alpha_trainable = self.trainable and self.fit_alpha
         with tf.name_scope(self.name):
             self.alpha = self.add_weight(
-                shape=[], initializer=self.alpha_initializer,
-                trainable=alpha_trainable, name="alpha", dtype=K.floatx(),
-                constraint=pk_constraints.GreaterEqualThan(min_value=0.000001)
+                shape=[],
+                initializer=self.alpha_initializer,
+                trainable=alpha_trainable,
+                name="alpha",
+                dtype=K.floatx(),
+                constraint=pk_constraints.GreaterEqualThan(min_value=0.000001),
             )
 
     def call(self, inputs):
@@ -100,21 +111,22 @@ class StudentsTSimilarity(tf.keras.layers.Layer):
 
         """
         return tf.pow(
-            1 + (tf.pow(inputs, self.tau) / self.alpha),
-            tf.negative(self.alpha + 1) / 2
+            1 + (tf.pow(inputs, self.tau) / self.alpha), tf.negative(self.alpha + 1) / 2
         )
 
     def get_config(self):
         """Return layer configuration."""
         config = super().get_config()
-        config.update({
-            'fit_tau': self.fit_tau,
-            'fit_alpha': self.fit_alpha,
-            'tau_initializer': tf.keras.initializers.serialize(
-                self.tau_initializer
-            ),
-            'alpha_initializer': tf.keras.initializers.serialize(
-                self.alpha_initializer
-            ),
-        })
+        config.update(
+            {
+                "fit_tau": self.fit_tau,
+                "fit_alpha": self.fit_alpha,
+                "tau_initializer": tf.keras.initializers.serialize(
+                    self.tau_initializer
+                ),
+                "alpha_initializer": tf.keras.initializers.serialize(
+                    self.alpha_initializer
+                ),
+            }
+        )
         return config
