@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ============================================================================
-"""Keras models initialization file."""
+"""Module of Keras models."""
 
 from psiz.keras.models.psych_embedding import PsychologicalEmbedding
 from psiz.keras.models.rank import Rank
@@ -21,8 +21,8 @@ from psiz.keras.models.rate import Rate
 from psiz.keras.models.stochastic_model import StochasticModel
 
 __all__ = [
-    'PsychologicalEmbedding',
-    'Rank',
-    'Rate',
-    'StochasticModel'
+    "PsychologicalEmbedding",
+    "Rank",
+    "Rate",
+    "StochasticModel",
 ]
