@@ -13,14 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ============================================================================
-"""Keras regularizers initialization file."""
+"""Module of Keras regularizers."""
 
 from psiz.keras.regularizers.attention_entropy import AttentionEntropy
 from psiz.keras.regularizers.squeeze import Squeeze
 from psiz.keras.regularizers.stimulus_normed_l1 import StimulusNormedL1
 
 __all__ = [
-    'AttentionEntropy',
-    'Squeeze',
-    'StimulusNormedL1'
+    "AttentionEntropy",
+    "Squeeze",
+    "StimulusNormedL1",
 ]
