@@ -23,11 +23,11 @@ Classes:
 import tensorflow as tf
 
 
-@tf.keras.utils.register_keras_serializable(package='psiz.keras.regularizers')
+@tf.keras.utils.register_keras_serializable(package="psiz.keras.regularizers")
 class AttentionEntropy(tf.keras.regularizers.Regularizer):
     """Entropy-based regularization to encourage sparsity."""
 
-    def __init__(self, rate=0.):
+    def __init__(self, rate=0.0):
         """Initialize.
 
         Args:
@@ -47,4 +47,4 @@ class AttentionEntropy(tf.keras.regularizers.Regularizer):
 
     def get_config(self):
         """Return config."""
-        return {'rate': float(self.rate)}
+        return {"rate": float(self.rate)}
