@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ============================================================================
-"""Initialization of `mplot` module."""
+"""Module of plotting functionality based on matplotlib."""
 
 from psiz.mplot.bvn_ellipse import bvn_ellipse
 from psiz.mplot.hdi_bvn import hdi_bvn
@@ -22,9 +22,9 @@ from psiz.mplot.embedding_input_dimension import embedding_input_dimension
 from psiz.mplot.embedding_output_dimension import embedding_output_dimension
 
 __all__ = [
-    'bvn_ellipse',
-    'hdi_bvn',
-    'heatmap_embeddings',
-    'embedding_input_dimension',
-    'embedding_output_dimension'
+    "bvn_ellipse",
+    "hdi_bvn",
+    "heatmap_embeddings",
+    "embedding_input_dimension",
+    "embedding_output_dimension",
 ]
