@@ -13,10 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ============================================================================
-"""Trials initialization."""
+"""Module of information theory functionality."""
 
 
 from psiz.tf.information_theory.ig_categorical import ig_categorical
 from psiz.tf.information_theory.ig_model_categorical import ig_model_categorical
 
-__all__ = ['ig_categorical', 'ig_model_categorical']
+__all__ = [
+    "ig_categorical",
+    "ig_model_categorical",
+]
