@@ -49,7 +49,7 @@ def wpnorm(x, w, p):
     w_abs_x_p = tf.multiply(abs_x_p, w)
     # Sum over last axis (i.e., `n_dim`).
     sum_x = tf.reduce_sum(w_abs_x_p, axis=-1, keepdims=True)
-    y = tf.pow(sum_x, 1. / p_exp)
+    y = tf.pow(sum_x, 1.0 / p_exp)
 
     def grad(dy):
         # Gradients of coordinates `x` with fudge factor to avoid problematic
@@ -57,26 +57,27 @@ def wpnorm(x, w, p):
         # shape=(batch_size, [n, m, ...] n_dim)
         dydx = dy * (
             (w * x * tf.math.divide_no_nan(abs_x_p, abs_x**2))
-            / (y**(p_exp - 1) + tf.keras.backend.epsilon())
+            / (y ** (p_exp - 1) + tf.keras.backend.epsilon())
         )
 
         # Gradients of weights `w` with fudge factor to avoid problematic
         # gradients.
         # shape=(batch_size, [n, m, ...] n_dim)
-        dydw = dy * (
-            abs_x_p / (p_exp * y**(p_exp - 1) + tf.keras.backend.epsilon())
-        )
+        dydw = dy * (abs_x_p / (p_exp * y ** (p_exp - 1) + tf.keras.backend.epsilon()))
 
         # Gradients of `p` with fudge factor and to avoid problematic
         # gradients.
         # shape=(batch_size, [n, m, ...])
-        p_0 = (1. / p_exp) * tf.math.divide_no_nan(y, sum_x) * tf.reduce_sum(
-            w_abs_x_p * tf.math.log(abs_x + tf.keras.backend.epsilon()),
-            axis=-1, keepdims=True
-        )
-        p_1 = (1. / p_exp**2) * y * tf.math.log(
-            sum_x + tf.keras.backend.epsilon()
+        p_0 = (
+            (1.0 / p_exp)
+            * tf.math.divide_no_nan(y, sum_x)
+            * tf.reduce_sum(
+                w_abs_x_p * tf.math.log(abs_x + tf.keras.backend.epsilon()),
+                axis=-1,
+                keepdims=True,
+            )
         )
+        p_1 = (1.0 / p_exp**2) * y * tf.math.log(sum_x + tf.keras.backend.epsilon())
         dydp = dy * (p_0 - p_1)
         dydp = tf.squeeze(dydp, [-1])
         return dydx, dydw, dydp
