@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ============================================================================
-"""Utilities initialization file."""
+"""Module of utilities."""
 
 from psiz.utils.affine_mvn import affine_mvn
 from psiz.utils.choice_wo_replace import choice_wo_replace
@@ -31,18 +31,18 @@ from psiz.utils.standard_split import standard_split
 from psiz.utils.stratified_group_kfold import StratifiedGroupKFold
 
 __all__ = [
-    'affine_mvn',
-    'choice_wo_replace',
-    'expand_dim_repeat',
-    'generate_group_matrix',
-    'm_prefer_n',
-    'pairwise_indices',
-    'pairwise_index_dataset',
-    'pairwise_similarity',
-    'procrustes_rotation',
-    'ProgressBarRe',
-    'rotation_matrix',
-    'random_combinations',
-    'standard_split',
-    'StratifiedGroupKFold'
+    "affine_mvn",
+    "choice_wo_replace",
+    "expand_dim_repeat",
+    "generate_group_matrix",
+    "m_prefer_n",
+    "pairwise_indices",
+    "pairwise_index_dataset",
+    "pairwise_similarity",
+    "procrustes_rotation",
+    "ProgressBarRe",
+    "rotation_matrix",
+    "random_combinations",
+    "standard_split",
+    "StratifiedGroupKFold",
 ]
